@@ -22,10 +22,13 @@
 
 #include "duchainutils.h"
 
+#include <algorithm>
+
 #include <interfaces/icore.h>
 #include <interfaces/ilanguagecontroller.h>
 
 #include "../interfaces/ilanguagesupport.h"
+#include "../assistant/staticassistantsmanager.h"
 #include "util/debug.h"
 
 #include "declaration.h"
@@ -289,77 +292,56 @@ TopDUContext* DUChainUtils::standardContextForUrl(const QUrl& url, bool preferPr
   return chosen;
 }
 
-Declaration* declarationUnderCursor(const CursorInRevision& c, DUContext* ctx)
+struct ItemUnderCursorInternal
 {
-  foreach( Declaration* decl, ctx->localDeclarations() )
-    if( decl->range().contains(c, RangeInRevision::IncludeBackEdge) )
-      return decl;
+  Declaration* declaration;
+  DUContext* context;
+  RangeInRevision range;
+};
 
+ItemUnderCursorInternal itemUnderCursorInternal(const CursorInRevision& c, DUContext* ctx, RangeInRevision::ContainsBehavior behavior)
+{
   //Search all collapsed sub-contexts. In C++, those can contain declarations that have ranges out of the context
-  foreach( DUContext* subCtx, ctx->childContexts() ) {
+  foreach(DUContext* subCtx, ctx->childContexts()) {
     //This is a little hacky, but we need it in case of foreach macros and similar stuff
-    if(subCtx->range().isEmpty() || subCtx->range().start.line == c.line || subCtx->range().end.line == c.line) {
-      Declaration* decl = declarationUnderCursor(c, subCtx);
-      if(decl)
-        return decl;
+    if(subCtx->range().contains(c, behavior) || subCtx->range().isEmpty() || subCtx->range().start.line == c.line || subCtx->range().end.line == c.line) {
+      ItemUnderCursorInternal sub = itemUnderCursorInternal(c, subCtx, behavior);
+      if(sub.declaration) {
+        return sub;
+      }
     }
   }
-  return 0;
+
+  foreach(Declaration* decl, ctx->localDeclarations()) {
+    if(decl->range().contains(c, behavior)) {
+      return {decl, ctx, decl->range()};
+    }
+  }
+
+  //Try finding a use under the cursor
+  for(int a = 0; a < ctx->usesCount(); ++a) {
+    if(ctx->uses()[a].m_range.contains(c, behavior)) {
+      return {ctx->topContext()->usedDeclarationForIndex(ctx->uses()[a].m_declarationIndex), ctx, ctx->uses()[a].m_range};
+    }
+  }
+
+  return {nullptr, nullptr, RangeInRevision()};
 }
 
-Declaration* DUChainUtils::itemUnderCursor(const QUrl& url, const KTextEditor::Cursor& _c)
+DUChainUtils::ItemUnderCursor DUChainUtils::itemUnderCursor(const QUrl& url, const KTextEditor::Cursor& cursor)
 {
-  KDevelop::TopDUContext* chosen = standardContextForUrl(url);
+  KDevelop::TopDUContext* top = standardContextForUrl(url.adjusted(QUrl::NormalizePathSegments));
 
-  if( chosen )
+  if(!top) {
+    return {nullptr, nullptr, KTextEditor::Range()};
+  }
+
+  ItemUnderCursorInternal decl = itemUnderCursorInternal(top->transformToLocalRevision(cursor), top, RangeInRevision::Default);
+  if (decl.declaration == nullptr)
   {
-    CursorInRevision c = chosen->transformToLocalRevision(_c);
-    DUContext* ctx = chosen->findContextAt(c);
-
-    while( ctx ) {
-      //Try finding a declaration under the cursor
-      Declaration* decl = declarationUnderCursor(c, ctx);
-      if(decl)
-        return decl;
-
-      //Try finding a use under the cursor
-      for(int a = 0; a < ctx->usesCount(); ++a)
-        if( ctx->uses()[a].m_range.contains(c, RangeInRevision::IncludeBackEdge) )
-          return ctx->topContext()->usedDeclarationForIndex(ctx->uses()[a].m_declarationIndex);
-
-      ctx = ctx->parentContext(); //It may happen, for example in the case of function-declarations, that the use is one context higher.
-    }
+    decl = itemUnderCursorInternal(top->transformToLocalRevision(cursor), top, RangeInRevision::IncludeBackEdge);
   }
-  return 0;
-}
-
-KTextEditor::Range DUChainUtils::itemRangeUnderCursor(const QUrl& url, const KTextEditor::Cursor& cursor)
-{
-  KDevelop::TopDUContext* chosen = standardContextForUrl(url);
-
-  if( chosen ) {
-    CursorInRevision c = chosen->transformToLocalRevision(cursor);
-    DUContext* ctx = chosen->findContextAt(c);
-    if (ctx) {
-      Declaration* decl = declarationUnderCursor(c, ctx);
-
-      // Some declarations need to be searched in parent context
-      if (!decl && ctx->parentContext()) {
-        decl = declarationUnderCursor(c, ctx->parentContext());
-      }
-
-      if (decl && decl->range().contains(c, RangeInRevision::IncludeBackEdge) ) {
-        return decl->rangeInCurrentRevision();
-      }
-
-      for(int a = 0; a < ctx->usesCount(); ++a) {
-        if( ctx->uses()[a].m_range.contains(c, RangeInRevision::IncludeBackEdge) ) {
-          return ctx->transformFromLocalRevision(ctx->uses()[a].m_range);
-        }
-      }
-    }
-  }
-  return KTextEditor::Range();
+  return {decl.declaration, decl.context, top->transformFromLocalRevision(decl.range)};
 }
 
 Declaration* DUChainUtils::declarationForDefinition(Declaration* definition, TopDUContext* topContext)
@@ -492,7 +474,7 @@ static QList<Declaration*> getInheritersInternal(const Declaration* decl, uint&
   if(maxAllowedSteps == 0)
     return ret;
 
-  if(decl->internalContext() && decl->internalContext()->type() == DUContext::Class)
+  if(decl->internalContext() && decl->internalContext()->type() == DUContext::Class) {
     foreach (const IndexedDUContext importer, decl->internalContext()->indexedImporters()) {
 
       DUContext* imp = importer.data();
@@ -508,9 +490,7 @@ static QList<Declaration*> getInheritersInternal(const Declaration* decl, uint&
       if(maxAllowedSteps == 0)
         return ret;
     }
-
-    if(maxAllowedSteps == 0)
-      return ret;
+  }
 
   if(collectVersions && decl->inSymbolTable()) {
     uint count;
@@ -632,3 +612,16 @@ DUContext* DUChainUtils::getFunctionContext(Declaration* decl) {
     return functionContext;
   return 0;
 }
+
+QVector<KDevelop::Problem::Ptr> KDevelop::DUChainUtils::allProblemsForContext(KDevelop::ReferencedTopDUContext top)
+{
+  QVector<KDevelop::Problem::Ptr> ret;
+  Q_FOREACH ( const auto& p, top->problems() ) {
+    ret << p;
+  }
+  Q_FOREACH ( const auto& p, ICore::self()->languageController()->staticAssistantsManager()->problemsForContext(top) ) {
+    ret << p;
+  }
+  return ret;
+}
+
