@@ -21,6 +21,8 @@
 
 #include "quickopenplugin.h"
 
+#include "quickopenwidget.h"
+
 #include <cassert>
 #include <typeinfo>
 #include <QTreeView>
@@ -32,6 +34,9 @@
 #include <QCheckBox>
 #include <QMetaObject>
 #include <QWidgetAction>
+#include <QMenuBar>
+#include <kparts/mainwindow.h>
+
 
 #include <KLocalizedString>
 #include <kpluginfactory.h>
@@ -45,6 +50,8 @@
 #include <kactioncollection.h>
 #include <QAction>
 
+#include <interfaces/icore.h>
+#include <interfaces/idocumentcontroller.h>
 #include <interfaces/icore.h>
 #include <interfaces/iuicontroller.h>
 #include <interfaces/idocumentcontroller.h>
@@ -58,8 +65,6 @@
 #include <serialization/indexedstring.h>
 #include <language/duchain/types/functiontype.h>
 
-#include "expandingtree/expandingdelegate.h"
-#include "ui_quickopen.h"
 #include "quickopenmodel.h"
 #include "projectfilequickopen.h"
 #include "projectitemquickopen.h"
@@ -127,20 +132,6 @@ class StandardQuickOpenWidgetCreator : public QuickOpenWidgetCreator {
     QStringList m_scopes;
 };
 
-class QuickOpenDelegate : public ExpandingDelegate {
-    Q_OBJECT
-public:
-  QuickOpenDelegate(ExpandingWidgetModel* model, QObject* parent = 0L) : ExpandingDelegate(model, parent) {
-  }
-  QList<QTextLayout::FormatRange> createHighlighting(const QModelIndex& index, QStyleOptionViewItem& option) const override {
-    QList<QVariant> highlighting = index.data(KTextEditor::CodeCompletionModel::CustomHighlight).toList();
-    if(!highlighting.isEmpty())
-      return highlightingFromVariantList(highlighting);
-    return ExpandingDelegate::createHighlighting( index, option );
-  }
-
-};
-
 class OutlineFilter : public DUChainUtils::DUChainItemFilter {
 public:
   enum OutlineMode { Functions, FunctionsAndClasses };
@@ -180,7 +171,7 @@ Declaration* cursorDeclaration() {
 
   KDevelop::DUChainReadLocker lock( DUChain::lock() );
 
-  return DUChainUtils::declarationForDefinition( DUChainUtils::itemUnderCursor( view->document()->url(), KTextEditor::Cursor(view->cursorPosition()) ) );
+  return DUChainUtils::declarationForDefinition( DUChainUtils::itemUnderCursor( view->document()->url(), KTextEditor::Cursor(view->cursorPosition()) ).declaration );
 }
 
 ///The first definition that belongs to a context that surrounds the current cursor
@@ -250,451 +241,6 @@ QuickOpenLineEdit* QuickOpenPlugin::createQuickOpenLineWidget()
   return new QuickOpenLineEdit(new StandardQuickOpenWidgetCreator(QStringList(), QStringList()));
 }
 
-void QuickOpenWidget::showStandardButtons(bool show)
-{
-  if(show) {
-    o.okButton->show();
-    o.cancelButton->show();
-  }else{
-    o.okButton->hide();
-    o.cancelButton->hide();
-  }
-}
-
-QuickOpenWidget::QuickOpenWidget( QString title, QuickOpenModel* model, const QStringList& initialItems, const QStringList& initialScopes, bool listOnly, bool noSearchField ) : m_model(model), m_expandedTemporary(false) {
-  m_filterTimer.setSingleShot(true);
-  connect(&m_filterTimer, &QTimer::timeout, this, &QuickOpenWidget::applyFilter);
-
-  Q_UNUSED( title );
-  o.setupUi( this );
-  o.list->header()->hide();
-  o.list->setRootIsDecorated( false );
-  o.list->setVerticalScrollMode( QAbstractItemView::ScrollPerItem );
-
-  connect(o.list->verticalScrollBar(), &QScrollBar::valueChanged, m_model, &QuickOpenModel::placeExpandingWidgets);
-
-  o.searchLine->setFocus();
-
-  o.list->setItemDelegate( new QuickOpenDelegate( m_model, o.list ) );
-
-  if(!listOnly) {
-    QStringList allTypes = m_model->allTypes();
-    QStringList allScopes = m_model->allScopes();
-
-    QMenu* itemsMenu = new QMenu;
-
-    foreach( const QString &type, allTypes )
-    {
-      QAction* action = new QAction(type, itemsMenu);
-      action->setCheckable(true);
-      action->setChecked(initialItems.isEmpty() || initialItems.contains( type ));
-      connect( action, &QAction::toggled, this, &QuickOpenWidget::updateProviders, Qt::QueuedConnection );
-      itemsMenu->addAction(action);
-    }
-
-    o.itemsButton->setMenu(itemsMenu);
-
-    QMenu* scopesMenu = new QMenu;
-
-    foreach( const QString &scope, allScopes )
-    {
-      QAction* action = new QAction(scope, scopesMenu);
-      action->setCheckable(true);
-      action->setChecked(initialScopes.isEmpty() || initialScopes.contains( scope ) );
-
-      connect( action, &QAction::toggled, this, &QuickOpenWidget::updateProviders, Qt::QueuedConnection );
-      scopesMenu->addAction(action);
-    }
-
-    o.scopesButton->setMenu(scopesMenu);
-
-  }else{
-    o.list->setFocusPolicy(Qt::StrongFocus);
-    o.scopesButton->hide();
-    o.itemsButton->hide();
-    o.label->hide();
-    o.label_2->hide();
-  }
-
-  showSearchField(!noSearchField);
-
-  o.okButton->hide();
-  o.cancelButton->hide();
-
-  o.searchLine->installEventFilter( this );
-  o.list->installEventFilter( this );
-  o.list->setFocusPolicy(Qt::NoFocus);
-  o.scopesButton->setFocusPolicy(Qt::NoFocus);
-  o.itemsButton->setFocusPolicy(Qt::NoFocus);
-
-  connect( o.searchLine, &QLineEdit::textChanged, this, &QuickOpenWidget::textChanged );
-
-  connect( o.list, &ExpandingTree::doubleClicked, this, &QuickOpenWidget::doubleClicked );
-
-  connect(o.okButton, &QPushButton::clicked, this, &QuickOpenWidget::accept);
-  connect(o.okButton, &QPushButton::clicked, this, &QuickOpenWidget::ready);
-  connect(o.cancelButton, &QPushButton::clicked, this, &QuickOpenWidget::ready);
-
-  updateProviders();
-  updateTimerInterval(true);
-
-// no need to call this, it's done by updateProviders already
-//   m_model->restart();
-}
-
-void QuickOpenWidget::updateTimerInterval(bool cheapFilterChange)
-{
-  const int MAX_ITEMS = 10000;
-  if ( cheapFilterChange && m_model->rowCount(QModelIndex()) < MAX_ITEMS ) {
-    // cheap change and there are currently just a few items,
-    // so apply filter instantly
-    m_filterTimer.setInterval(0);
-  } else if ( m_model->unfilteredRowCount() < MAX_ITEMS ) {
-    // not a cheap change, but there are generally
-    // just a few items in the list: apply filter instantly
-    m_filterTimer.setInterval(0);
-  } else {
-    // otherwise use a timer to prevent sluggishness while typing
-    m_filterTimer.setInterval(300);
-  }
-}
-
-void QuickOpenWidget::showEvent(QShowEvent* e)
-{
-    QWidget::showEvent(e);
-
-    // The column width only has an effect _after_ the widget has been shown
-    o.list->setColumnWidth( 0, 20 );
-}
-
-void QuickOpenWidget::setAlternativeSearchField(QLineEdit* alterantiveSearchField)
-{
-    o.searchLine = alterantiveSearchField;
-    o.searchLine->installEventFilter( this );
-    connect( o.searchLine, &QLineEdit::textChanged, this, &QuickOpenWidget::textChanged );
-}
-
-
-void QuickOpenWidget::showSearchField(bool b)
-{
-    if(b){
-      o.searchLine->show();
-      o.searchLabel->show();
-    }else{
-      o.searchLine->hide();
-      o.searchLabel->hide();
-    }
-}
-
-void QuickOpenWidget::prepareShow()
-{
-  o.list->setModel( 0 );
-  o.list->setVerticalScrollMode(QAbstractItemView::ScrollPerItem);
-  m_model->setTreeView( o.list );
-  o.list->setModel( m_model );
-
-  m_filterTimer.stop();
-  m_filter = QString();
-
-  if (!m_preselectedText.isEmpty())
-  {
-    o.searchLine->setText(m_preselectedText);
-    o.searchLine->selectAll();
-  }
-
-  m_model->restart(false);
-
-  connect( o.list->selectionModel(), &QItemSelectionModel::currentRowChanged,
-           this, &QuickOpenWidget::callRowSelected );
-  connect( o.list->selectionModel(), &QItemSelectionModel::selectionChanged,
-           this, &QuickOpenWidget::callRowSelected );
-}
-
-void QuickOpenWidgetDialog::run() {
-  m_widget->prepareShow();
-  m_dialog->show();
-}
-
-QuickOpenWidget::~QuickOpenWidget() {
-  m_model->setTreeView( 0 );
-}
-
-
-QuickOpenWidgetDialog::QuickOpenWidgetDialog(QString title, QuickOpenModel* model, const QStringList& initialItems, const QStringList& initialScopes, bool listOnly, bool noSearchField)
-{
-  m_widget = new QuickOpenWidget(title, model, initialItems, initialScopes, listOnly, noSearchField);
-  // the QMenu might close on esc and we want to close the whole dialog then
-  connect( m_widget, &QuickOpenWidget::aboutToHide, this, &QuickOpenWidgetDialog::deleteLater );
-
-  m_dialog = new QDialog( ICore::self()->uiController()->activeMainWindow() );
-  m_dialog->resize(QSize(800, 400));
-
-  m_dialog->setWindowTitle(title);
-  QVBoxLayout* layout = new QVBoxLayout(m_dialog);
-  layout->addWidget(m_widget);
-  m_widget->showStandardButtons(true);
-  connect(m_widget, &QuickOpenWidget::ready, m_dialog, &QDialog::close);
-  connect( m_dialog, &QDialog::accepted, m_widget, &QuickOpenWidget::accept );
-}
-
-
-QuickOpenWidgetDialog::~QuickOpenWidgetDialog()
-{
-  delete m_dialog;
-}
-
-void QuickOpenWidget::setPreselectedText(const QString& text)
-{
-  m_preselectedText = text;
-}
-
-void QuickOpenWidget::updateProviders() {
-  if(QAction* action = qobject_cast<QAction*>(sender())) {
-    QMenu* menu = qobject_cast<QMenu*>(action->parentWidget());
-    if(menu) {
-      menu->show();
-      menu->setActiveAction(action);
-    }
-  }
-
-  QStringList checkedItems;
-
-  if(o.itemsButton->menu()) {
-
-    foreach( QObject* obj, o.itemsButton->menu()->children() ) {
-      QAction* box = qobject_cast<QAction*>( obj );
-      if( box ) {
-        if( box->isChecked() )
-          checkedItems << box->text().remove('&');
-      }
-    }
-    o.itemsButton->setText(checkedItems.join(QStringLiteral(", ")));
-  }
-
-  QStringList checkedScopes;
-
-  if(o.scopesButton->menu()) {
-
-    foreach( QObject* obj, o.scopesButton->menu()->children() ) {
-      QAction* box = qobject_cast<QAction*>( obj );
-      if( box ) {
-        if( box->isChecked() )
-          checkedScopes << box->text().remove('&');
-      }
-    }
-
-    o.scopesButton->setText(checkedScopes.join(QStringLiteral(", ")));
-  }
-
-  emit itemsChanged( checkedItems );
-  emit scopesChanged( checkedScopes );
-  m_model->enableProviders( checkedItems, checkedScopes );
-}
-
-void QuickOpenWidget::textChanged( const QString& str )
-{
-  // "cheap" when something was just appended to the current filter
-  updateTimerInterval(str.startsWith(m_filter));
-  m_filter = str;
-  m_filterTimer.start();
-}
-
-void QuickOpenWidget::applyFilter()
-{
-  m_model->textChanged( m_filter );
-
-  QModelIndex currentIndex = m_model->index(0, 0, QModelIndex());
-  o.list->selectionModel()->setCurrentIndex( currentIndex, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows | QItemSelectionModel::Current );
-
-  callRowSelected();
-}
-
-void QuickOpenWidget::callRowSelected() {
-  QModelIndex currentIndex = o.list->selectionModel()->currentIndex();
-  if( currentIndex.isValid() )
-    m_model->rowSelected( currentIndex );
-  else
-    qCDebug(PLUGIN_QUICKOPEN) << "current index is not valid";
-}
-
-void QuickOpenWidget::accept() {
-  QString filterText = o.searchLine->text();
-  m_model->execute( o.list->currentIndex(), filterText );
-}
-
-void QuickOpenWidget::doubleClicked ( const QModelIndex & index ) {
-  // crash guard: https://bugs.kde.org/show_bug.cgi?id=297178
-  o.list->setCurrentIndex(index);
-  QMetaObject::invokeMethod(this, "accept", Qt::QueuedConnection);
-  QMetaObject::invokeMethod(this, "ready", Qt::QueuedConnection);
-}
-
-bool QuickOpenWidget::eventFilter ( QObject * watched, QEvent * event )
-{
-  QKeyEvent *keyEvent = dynamic_cast<QKeyEvent*>(event);
-
-  if( event->type() == QEvent::KeyRelease ) {
-    if(keyEvent->key() == Qt::Key_Alt) {
-      if((m_expandedTemporary && m_altDownTime.msecsTo( QTime::currentTime() ) > 300) || (!m_expandedTemporary && m_altDownTime.msecsTo( QTime::currentTime() ) < 300 && m_hadNoCommandSinceAlt)) {
-        //Unexpand the item
-        QModelIndex row = o.list->selectionModel()->currentIndex();
-        if( row.isValid() ) {
-          row = row.sibling( row.row(), 0 );
-          if(m_model->isExpanded( row ))
-            m_model->setExpanded( row, false );
-        }
-      }
-      m_expandedTemporary = false;
-    }
-  }
-
-  if( event->type() == QEvent::KeyPress  ) {
-    m_hadNoCommandSinceAlt = false;
-    if(keyEvent->key() == Qt::Key_Alt) {
-      m_hadNoCommandSinceAlt = true;
-      //Expand
-      QModelIndex row = o.list->selectionModel()->currentIndex();
-      if( row.isValid() ) {
-        row = row.sibling( row.row(), 0 );
-        m_altDownTime = QTime::currentTime();
-        if(!m_model->isExpanded( row )) {
-          m_expandedTemporary = true;
-          m_model->setExpanded( row, true );
-        }
-      }
-    }
-
-    switch( keyEvent->key() ) {
-      case Qt::Key_Tab:
-        if ( keyEvent->modifiers() == Qt::NoModifier ) {
-          // Tab should work just like Down
-          QCoreApplication::sendEvent(o.list, new QKeyEvent(QEvent::KeyPress, Qt::Key_Down, Qt::NoModifier));
-          QCoreApplication::sendEvent(o.list, new QKeyEvent(QEvent::KeyRelease, Qt::Key_Down, Qt::NoModifier));
-          return true;
-        }
-        break;
-      case Qt::Key_Backtab:
-         if ( keyEvent->modifiers() == Qt::ShiftModifier ) {
-          // Shift + Tab should work just like Up
-          QCoreApplication::sendEvent(o.list, new QKeyEvent(QEvent::KeyPress, Qt::Key_Up, Qt::NoModifier));
-          QCoreApplication::sendEvent(o.list, new QKeyEvent(QEvent::KeyRelease, Qt::Key_Up, Qt::NoModifier));
-          return true;
-        }
-        break;
-      case Qt::Key_Down:
-      case Qt::Key_Up:
-      {
-        if( keyEvent->modifiers() == Qt::AltModifier ) {
-          QWidget* w = m_model->expandingWidget(o.list->selectionModel()->currentIndex());
-          if( KDevelop::QuickOpenEmbeddedWidgetInterface* interface =
-              dynamic_cast<KDevelop::QuickOpenEmbeddedWidgetInterface*>( w ) ){
-            if( keyEvent->key() == Qt::Key_Down )
-              interface->down();
-            else
-              interface->up();
-            return true;
-          }
-          return false;
-        }
-      }
-      case Qt::Key_PageUp:
-      case Qt::Key_PageDown:
-        if(watched == o.list )
-          return false;
-        QApplication::sendEvent( o.list, event );
-      //callRowSelected();
-        return true;
-
-      case Qt::Key_Left: {
-        //Expand/unexpand
-        if( keyEvent->modifiers() == Qt::AltModifier ) {
-          //Eventually Send action to the widget
-          QWidget* w = m_model->expandingWidget(o.list->selectionModel()->currentIndex());
-          if( KDevelop::QuickOpenEmbeddedWidgetInterface* interface =
-              dynamic_cast<KDevelop::QuickOpenEmbeddedWidgetInterface*>( w ) ){
-            interface->previous();
-            return true;
-          }
-        } else {
-          QModelIndex row = o.list->selectionModel()->currentIndex();
-          if( row.isValid() ) {
-            row = row.sibling( row.row(), 0 );
-
-            if( m_model->isExpanded( row ) ) {
-              m_model->setExpanded( row, false );
-              return true;
-            }
-          }
-        }
-        return false;
-      }
-      case Qt::Key_Right: {
-        //Expand/unexpand
-        if( keyEvent->modifiers() == Qt::AltModifier ) {
-          //Eventually Send action to the widget
-          QWidget* w = m_model->expandingWidget(o.list->selectionModel()->currentIndex());
-          if( KDevelop::QuickOpenEmbeddedWidgetInterface* interface =
-              dynamic_cast<KDevelop::QuickOpenEmbeddedWidgetInterface*>( w ) ){
-            interface->next();
-            return true;
-          }
-        } else {
-          QModelIndex row = o.list->selectionModel()->currentIndex();
-          if( row.isValid() ) {
-            row = row.sibling( row.row(), 0 );
-
-            if( !m_model->isExpanded( row ) ) {
-              m_model->setExpanded( row, true );
-              return true;
-            }
-          }
-        }
-        return false;
-      }
-      case Qt::Key_Return:
-      case Qt::Key_Enter: {
-        if (m_filterTimer.isActive()) {
-          m_filterTimer.stop();
-          applyFilter();
-        }
-        if( keyEvent->modifiers() == Qt::AltModifier ) {
-          //Eventually Send action to the widget
-          QWidget* w = m_model->expandingWidget(o.list->selectionModel()->currentIndex());
-          if( KDevelop::QuickOpenEmbeddedWidgetInterface* interface =
-              dynamic_cast<KDevelop::QuickOpenEmbeddedWidgetInterface*>( w ) ){
-            interface->accept();
-            return true;
-          }
-        } else {
-          QString filterText = o.searchLine->text();
-
-          //Safety: Track whether this object is deleted. When execute() is called, a dialog may be opened,
-          //which kills the quickopen widget.
-          QPointer<QObject> stillExists(this);
-
-          if( m_model->execute( o.list->currentIndex(), filterText ) ) {
-
-            if(!stillExists)
-              return true;
-
-            if(!(keyEvent->modifiers() & Qt::ShiftModifier))
-              emit ready();
-          } else {
-            //Maybe the filter-text was changed:
-            if( filterText != o.searchLine->text() ) {
-              o.searchLine->setText( filterText );
-            }
-          }
-        }
-        return true;
-      }
-    }
-  }
-
-  return false;
-}
-
-
 QuickOpenLineEdit* QuickOpenPlugin::quickOpenLine(QString name)
 {
   QList< QuickOpenLineEdit* > lines = ICore::self()->uiController()->activeMainWindow()->findChildren<QuickOpenLineEdit*>(name);
@@ -942,7 +488,7 @@ void QuickOpenPlugin::showQuickOpenWidget(const QStringList& items, const QStrin
   connect( dialog->widget(), &QuickOpenWidget::scopesChanged, this, &QuickOpenPlugin::storeScopes );
   //Not connecting itemsChanged to storeItems, as showQuickOpen doesn't use lastUsedItems and so shouldn't store item changes
   //connect( dialog->widget(), SIGNAL(itemsChanged(QStringList)), this, SLOT(storeItems(QStringList)) );
-  dialog->widget()->o.itemsButton->setEnabled(false);
+  dialog->widget()->ui.itemsButton->setEnabled(false);
 
   if(quickOpenLine()) {
     quickOpenLine()->showWithWidget(dialog->widget());
@@ -1257,8 +803,13 @@ struct CreateOutlineDialog {
       int num = 0;
       foreach(const DUChainItem& item, items) {
         if(item.m_item.data() == cursorDecl) {
-          dialog->widget()->o.list->setCurrentIndex( model->index(num,0,QModelIndex()) );
-          dialog->widget()->o.list->scrollTo( model->index(num,0,QModelIndex()), QAbstractItemView::PositionAtCenter );
+          QModelIndex index(model->index(num,0,QModelIndex()));
+          // Need to invoke the scrolling later. If we did it now, then it wouldn't have any effect,
+          // apparently because the widget internals aren't initialized yet properly (although we've
+          // already called 'widget->show()'.
+          auto list = dialog->widget()->ui.list;
+          QMetaObject::invokeMethod(list, "setCurrentIndex", Qt::QueuedConnection, Q_ARG(QModelIndex, index));
+          QMetaObject::invokeMethod(list, "scrollTo", Qt::QueuedConnection, Q_ARG(QModelIndex, index), Q_ARG(QAbstractItemView::ScrollHint, QAbstractItemView::PositionAtCenter));
         }
         ++num;
       }
@@ -1421,7 +972,7 @@ void QuickOpenLineEdit::focusInEvent(QFocusEvent* ev) {
 
     connect( m_widget.data(), &QuickOpenWidget::scopesChanged, QuickOpenPlugin::self(), &QuickOpenPlugin::storeScopes );
     connect( m_widget.data(), &QuickOpenWidget::itemsChanged, QuickOpenPlugin::self(), &QuickOpenPlugin::storeItems );
-    Q_ASSERT(m_widget->o.searchLine == this);
+    Q_ASSERT(m_widget->ui.searchLine == this);
     m_widget->prepareShow();
     QRect widgetGeometry = QRect(mapToGlobal(QPoint(0, height())), mapToGlobal(QPoint(width(), height() + 400)));
     widgetGeometry.setWidth(700); ///@todo Waste less space
@@ -1459,10 +1010,9 @@ bool QuickOpenLineEdit::eventFilter(QObject* obj, QEvent* e) {
           return true;
       }
       break;
-     case QEvent::WindowActivate:
+    case QEvent::WindowActivate:
     case QEvent::WindowDeactivate:
-        qCDebug(PLUGIN_QUICKOPEN) << "closing because of window activation";
-        deactivate();
+        QMetaObject::invokeMethod(this, "checkFocus", Qt::QueuedConnection);
         break;
     // handle bug 260657 - "Outline menu doesn't follow main window on its move"
     case QEvent::Move: {
@@ -1492,6 +1042,10 @@ bool QuickOpenLineEdit::eventFilter(QObject* obj, QEvent* e) {
             if (!insideThis(obj))
                 deactivate();
         }
+        else if(obj != this)
+        {
+            QMetaObject::invokeMethod(this, "checkFocus", Qt::QueuedConnection);
+        }        
         break;
     default:
         break;
@@ -1517,17 +1071,22 @@ void QuickOpenLineEdit::deactivate() {
 
     m_widget = 0;
     qApp->removeEventFilter(this);
-
 }
 
 void QuickOpenLineEdit::checkFocus()
 {
     qCDebug(PLUGIN_QUICKOPEN) << "checking focus" << m_widget;
     if(m_widget) {
-      if(isVisible() && !isHidden())
-        setFocus();
-      else
-        deactivate();
+      QWidget* focusWidget = QApplication::focusWidget();
+      bool focusWidgetInsideThis = focusWidget ? insideThis(focusWidget) : false;
+      if(QApplication::focusWindow() && isVisible() && !isHidden() && (!focusWidget || (focusWidget && focusWidgetInsideThis))) {
+          qCDebug(PLUGIN_QUICKOPEN) << "setting focus to line edit";
+          activateWindow();
+          setFocus();
+      } else {
+          qCDebug(PLUGIN_QUICKOPEN) << "deactivating because check failed, focusWidget" << focusWidget << "insideThis" << focusWidgetInsideThis;
+          deactivate();
+      }
     }else{
        if (ICore::self()->documentController()->activeDocument())
            ICore::self()->documentController()->activateDocument(ICore::self()->documentController()->activeDocument());
@@ -1547,5 +1106,3 @@ IQuickOpenLine* QuickOpenPlugin::createQuickOpenLine(const QStringList& scopes,
 }
 
 #include "quickopenplugin.moc"
-
-// kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
