@@ -39,7 +39,7 @@ Boston, MA 02110-1301, USA.
 #include <KTextEditor/MainWindow>
 #include <KWindowSystem>
 #include <KXMLGUIFactory>
-#include <KColorScheme>
+#include <kparts_version.h>
 
 #include <sublime/area.h>
 #include "shellextension.h"
@@ -72,15 +72,14 @@ namespace {
 
 QColor defaultColor(const QPalette& palette)
 {
-    const KColorScheme scheme(palette.currentColorGroup());
-    return scheme.foreground(KColorScheme::NormalText).color();
+    return palette.foreground().color();
 }
 
-QColor colorForDocument(const QUrl& url, const QPalette& palette)
+QColor colorForDocument(const QUrl& url, const QPalette& palette, const QColor& defaultColor)
 {
     auto project = Core::self()->projectController()->findProjectForUrl(url);
     if (!project)
-        return QColor();
+        return defaultColor;
 
     return WidgetColorizer::colorForId(qHash(project->path()), palette);
 }
@@ -95,23 +94,25 @@ void MainWindow::applyMainWindowSettings(const KConfigGroup& config)
 
 void MainWindow::createGUI(KParts::Part* part)
 {
+    //TODO remove if-clause once KF5 >= 5.24 is required
+#if KPARTS_VERSION_MINOR >= 24
+    Sublime::MainWindow::setWindowTitleHandling(false);
     Sublime::MainWindow::createGUI(part);
-
-    // Don't let the Part control the main window caption -- we take care of that
-    disconnect(part, SIGNAL(setWindowCaption(QString)),
-               this, SLOT(setCaption(QString)));
+#else
+    Sublime::MainWindow::createGUI(part);
+    if (part) {
+        // Don't let the Part control the main window caption -- we take care of that
+        disconnect(part, SIGNAL(setWindowCaption(QString)),
+                   this, SLOT(setCaption(QString)));
+    }
+#endif
 }
 
-MainWindow::MainWindow( Sublime::Controller *parent, Qt::WindowFlags flags )
-        : Sublime::MainWindow( parent, flags )
+void MainWindow::initializeCorners()
 {
-    QDBusConnection::sessionBus().registerObject( QStringLiteral("/kdevelop/MainWindow"),
-        this, QDBusConnection::ExportScriptableSlots );
-
-    setAcceptDrops( true );
-    KConfigGroup cg = KSharedConfig::openConfig()->group( "UiSettings" );
-    int bottomleft = cg.readEntry( "BottomLeftCornerOwner", 0 );
-    int bottomright = cg.readEntry( "BottomRightCornerOwner", 0 );
+    const KConfigGroup cg = KSharedConfig::openConfig()->group( "UiSettings" );
+    const int bottomleft = cg.readEntry( "BottomLeftCornerOwner", 0 );
+    const int bottomright = cg.readEntry( "BottomRightCornerOwner", 0 );
     qCDebug(SHELL) << "Bottom Left:" << bottomleft;
     qCDebug(SHELL) << "Bottom Right:" << bottomright;
 
@@ -125,6 +126,16 @@ MainWindow::MainWindow( Sublime::Controller *parent, Qt::WindowFlags flags )
         setCorner( Qt::BottomRightCorner, Qt::RightDockWidgetArea );
     else if( bottomright == 1 )
         setCorner( Qt::BottomRightCorner, Qt::BottomDockWidgetArea );
+}
+
+MainWindow::MainWindow( Sublime::Controller *parent, Qt::WindowFlags flags )
+        : Sublime::MainWindow( parent, flags )
+{
+    QDBusConnection::sessionBus().registerObject( QStringLiteral("/kdevelop/MainWindow"),
+        this, QDBusConnection::ExportScriptableSlots );
+
+    setAcceptDrops( true );
+    initializeCorners();
 
     setObjectName( QStringLiteral("MainWindow") );
     d = new MainWindowPrivate(this);
@@ -213,24 +224,7 @@ void MainWindow::dropEvent( QDropEvent* ev )
 void MainWindow::loadSettings()
 {
     qCDebug(SHELL) << "Loading Settings";
-    KConfigGroup cg = KSharedConfig::openConfig()->group( "UiSettings" );
-
-    // dock widget corner layout
-    int bottomleft = cg.readEntry( "BottomLeftCornerOwner", 0 );
-    int bottomright = cg.readEntry( "BottomRightCornerOwner", 0 );
-    qCDebug(SHELL) << "Bottom Left:" << bottomleft;
-    qCDebug(SHELL) << "Bottom Right:" << bottomright;
-
-    // 0 means vertical dock (left, right), 1 means horizontal dock( top, bottom )
-    if( bottomleft == 0 )
-        setCorner( Qt::BottomLeftCorner, Qt::LeftDockWidgetArea );
-    else if( bottomleft == 1 )
-        setCorner( Qt::BottomLeftCorner, Qt::BottomDockWidgetArea );
-
-    if( bottomright == 0 )
-        setCorner( Qt::BottomRightCorner, Qt::RightDockWidgetArea );
-    else if( bottomright == 1 )
-        setCorner( Qt::BottomRightCorner, Qt::BottomDockWidgetArea );
+    initializeCorners();
 
     updateAllTabColors();
 
@@ -320,9 +314,11 @@ void MainWindow::initialize()
 
     guiFactory()->addClient(Core::self()->sessionController());
     guiFactory()->addClient(Core::self()->sourceFormatterControllerInternal());
+
     // Needed to re-plug the actions from the sessioncontroller as xmlguiclients don't
     // seem to remember which actions where plugged in.
-    Core::self()->sessionController()->plugActions();
+    Core::self()->sessionController()->updateXmlGuiActionList();
+
     d->setupGui();
 
     //Queued so we process it with some delay, to make sure the rest of the UI has already adapted
@@ -361,7 +357,10 @@ bool MainWindow::queryClose()
 void MainWindow::updateActiveDocumentConnection(IDocument* document)
 {
     disconnect(d->activeDocumentReadWriteConnection);
-    d->activeDocumentReadWriteConnection = connect(document->textDocument(), &KTextEditor::Document::readWriteChanged, this, &MainWindow::updateCaption);
+    if (auto textDocument = document->textDocument()) {
+        d->activeDocumentReadWriteConnection = connect(textDocument, &KTextEditor::Document::readWriteChanged,
+                                                       this, &MainWindow::updateCaption);
+    }
 }
 
 void MainWindow::updateCaption()
@@ -398,15 +397,19 @@ void MainWindow::updateAllTabColors()
         return;
 
     const auto defaultColor = ::defaultColor(palette());
-    if (UiConfig::colorizeByProject()){
+    if (UiConfig::colorizeByProject()) {
+        QHash<const Sublime::View*, QColor> viewColors;
         foreach (auto container, containers()) {
-            foreach (auto view, container->views()) {
+            auto views = container->views();
+            viewColors.reserve(views.size());
+            viewColors.clear();
+            foreach (auto view, views) {
                 const auto urlDoc = qobject_cast<Sublime::UrlDocument*>(view->document());
                 if (urlDoc) {
-                    const auto color = colorForDocument(urlDoc->url(), palette());
-                    container->setTabColor(view, color.isValid() ? color : defaultColor);
+                    viewColors[view] = colorForDocument(urlDoc->url(), palette(), defaultColor);
                 }
             }
+            container->setTabColors(viewColors);
         }
     } else {
         foreach (auto container, containers()) {
@@ -420,13 +423,12 @@ void MainWindow::updateTabColor(IDocument* doc)
     if (!UiConfig::self()->colorizeByProject())
         return;
 
-    const auto defaultColor = ::defaultColor(palette());
-    const auto color = colorForDocument(doc->url(), palette());
+    const auto color = colorForDocument(doc->url(), palette(), defaultColor(palette()));
     foreach (auto container, containers()) {
         foreach (auto view, container->views()) {
             const auto urlDoc = qobject_cast<Sublime::UrlDocument*>(view->document());
             if (urlDoc && urlDoc->url() == doc->url()) {
-                container->setTabColor(view, color.isValid() ? color : defaultColor);
+                container->setTabColor(view, color);
             }
         }
     }
