@@ -26,6 +26,7 @@
 #include <sublime/area.h>
 #include <sublime/view.h>
 #include <sublime/mainwindow.h>
+#include <iprojectcontroller.h>
 
 #include "core.h"
 #include "uicontroller.h"
@@ -98,28 +99,23 @@ bool PartDocument::save(DocumentSaveMode /*mode*/)
 
 bool PartDocument::askForCloseFeedback()
 {
+    int code = -1;
     if (state() == IDocument::Modified) {
-        int code = KMessageBox::warningYesNoCancel(
+        code = KMessageBox::warningYesNoCancel(
             Core::self()->uiController()->activeMainWindow(),
             i18n("The document \"%1\" has unsaved changes. Would you like to save them?", url().toLocalFile()),
             i18n("Close Document"));
 
-        if (code == KMessageBox::Yes) {
-            if (!save(Default))
-                return false;
-
-        } else if (code == KMessageBox::Cancel) {
-            return false;
-        }
-
     /// @todo Is this behavior right?
     } else if (state() == IDocument::DirtyAndModified) {
-        int code = KMessageBox::warningYesNoCancel(
+        code = KMessageBox::warningYesNoCancel(
             Core::self()->uiController()->activeMainWindow(),
             i18n("The document \"%1\" has unsaved changes and was modified by an external process.\n"
                  "Do you want to override the external changes?", url().toLocalFile()),
             i18n("Close Document"));
+    }
 
+    if (code >= 0) {
         if (code == KMessageBox::Yes) {
             if (!save(Default))
                 return false;
@@ -127,8 +123,8 @@ bool PartDocument::askForCloseFeedback()
         } else if (code == KMessageBox::Cancel) {
             return false;
         }
-
     }
+
     return true;
 }
 
@@ -214,7 +210,7 @@ void PartDocument::setPrettyName(QString name)
     if(!name.isEmpty())
         setTitle(name);
     else
-        setTitle(url().fileName());
+        setTitle(Core::self()->projectController()->prettyFileName(url(), KDevelop::IProjectController::FormatPlain));
 }
 
 QMap<QWidget*, KParts::Part*> PartDocument::partForView() const
